@@ -1,11 +1,12 @@
 package CLDR::Number::Format::Decimal;
 
 use utf8;
-use Moo;
 use Carp;
+
+use Moo;
 use namespace::clean;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 with qw( CLDR::Number::Role::Format );
 
@@ -33,10 +34,8 @@ sub BUILD {}
 sub format {
     my ($self, $num) = @_;
 
-    if (!defined $num) {
-        carp 'Use of uninitialized value in format';
-        return undef;
-    }
+    $num = $self->_validate_number(format => $num);
+    return undef unless defined $num;
 
     return $self->_format_number($num);
 }
@@ -53,9 +52,8 @@ CLDR::Number::Format::Decimal - Localized decimal formatter using the Unicode CL
 
 =head1 VERSION
 
-This document describes CLDR::Number::Format::Decimal v0.04, built with the
-Unicode CLDR v24. This is an early release without full documentation. See
-L<CLDR::Number::TODO>.
+This document describes CLDR::Number::Format::Decimal v0.05, built with Unicode
+CLDR v24.
 
 =head1 SYNOPSIS
 
