@@ -1,12 +1,13 @@
 package CLDR::Number::Format::Percent;
 
 use utf8;
-use Moo;
 use Carp;
 use CLDR::Number::Constant qw( $P );
+
+use Moo;
 use namespace::clean;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 with qw( CLDR::Number::Role::Format );
 
@@ -41,10 +42,8 @@ sub format {
     my ($self, $num) = @_;
     my ($factor, $sign);
 
-    if (!defined $num) {
-        carp 'Use of uninitialized value in format';
-        return undef;
-    }
+    $num = $self->_validate_number(format => $num);
+    return undef unless defined $num;
 
     if ($self->permil) {
         $factor = 1_000;
@@ -73,9 +72,8 @@ CLDR::Number::Format::Percent - Localized percent formatter using the Unicode CL
 
 =head1 VERSION
 
-This document describes CLDR::Number::Format::Percent v0.04, built with the
-Unicode CLDR v24. This is an early release without full documentation. See
-L<CLDR::Number::TODO>.
+This document describes CLDR::Number::Format::Percent v0.05, built with Unicode
+CLDR v24.
 
 =head1 SYNOPSIS
 
